| local_install_deps | R Documentation |
Installs the hard dependencies of a package tree (or source package file), without installing the package tree itself.
local_install_deps(
root = ".",
lib = .libPaths()[1],
upgrade = TRUE,
ask = interactive(),
dependencies = NA
)
root |
Path to the package tree. |
lib |
Character vector of library paths to consider when creating the installation plan.
|
upgrade |
When When |
ask |
Whether to ask for confirmation when installing a different version of a package that is already installed. Installations that only add new packages never require confirmation. |
dependencies |
What kinds of dependencies to install. Most commonly one of the following values:
|
Note that development (and optional) dependencies, under Suggests in
DESCRIPTION, are not installed. If you want to install them as well,
use local_install_dev_deps().
Data frame, with information about the installed package(s).
Other local package trees:
local_deps(),
local_deps_explain(),
local_install(),
local_install_dev_deps(),
local_package_trees,
pak()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.