| local_install_dev_deps | R Documentation |
Installs all dependencies of a package tree (or source package file),
without installing the package tree itself. It installs the development
dependencies as well, specified in the Suggests field of
DESCRIPTION.
local_install_dev_deps(
root = ".",
lib = .libPaths()[1],
upgrade = TRUE,
ask = interactive(),
dependencies = TRUE
)
root |
Path to the package tree. |
lib |
Character vector of library paths to consider when creating the installation plan.
|
upgrade |
When When |
ask |
Whether to ask for confirmation when installing a different version of a package that is already installed. Installations that only add new packages never require confirmation. |
dependencies |
What kinds of dependencies to install. Most commonly one of the following values:
|
Other local package trees:
local_deps(),
local_deps_explain(),
local_install(),
local_install_deps(),
local_package_trees,
pak()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.