| lockfile_create | R Documentation |
The lock file can be used later, possibly in a new R session, to carry
out the installation of the dependencies, with
lockfile_install().
lockfile_create(
pkg = "deps::.",
lockfile = "pkg.lock",
lib = NULL,
upgrade = FALSE,
dependencies = NA
)
pkg |
Package names or package references. E.g.
See "Package sources" for more details. |
lockfile |
Path to the lock file. |
lib |
Character vector of library paths, or |
upgrade |
When When |
dependencies |
What kinds of dependencies to install. Most commonly one of the following values:
|
Note, since the URLs of CRAN and most CRAN-like repositories change over time, in practice you cannot use the lock file much later. For example, binary packages of older package version might be deleted from the repository, breaking the URLs in the lock file.
Currently the intended use case of lock files in on CI systems, to facilitate caching. The (hash of the) lock file provides a good key for caching systems.
Other lock files:
lockfile_install()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.