R/lockfile.R
lockfile_install.Rd
Install a lock file that was created with lockfile_create().
lockfile_create()
lockfile_install(lockfile = "pkg.lock", lib = NULL, update = TRUE)
Path to the lock file.
Library to carry out the installation on.
Whether to only install the packages that either not installed in lib, or a different version is installed for them.
lib
Other lock files: lockfile_create()