The format of a repository specification is a named or unnamed
character scalar. If the name is missing, pak adds a name
automatically. The repository named CRAN is the main CRAN repository,
but otherwise names are informational.
URL pointing to the root of the CRAN-like repository. Example:
https://cloud.r-project.org
RSPM@<date>, RSPM (RStudio Package Manager) snapshot, at the
specified date.
RSPM@<package>-<version> RSPM snapshot, for the day after the
release of <version> of <package>.
RSPM@R-<version> RSPM snapshot, for the day after R <version>
was released.
MRAN@<date>, MRAN (Microsoft R Application Network) snapshot, at
the specified date.
MRAN@<package>-<version> MRAN snapshot, for the
day after the release of <version> of <package>.
MRAN@R-<version> MRAN snapshot, for the day
after R <version> was released.